package exampleSet1;
import java.awt.*;
import javax.swing.*;

/**
 * <code>DemoBasic_v2</code> is a trivial interface that has a simple
 * component, a JLabel (just like <code>DemoBasic_v1</code>). However,
 * DemoBasic_v2 demonstrates the addition of a component to the content pane
 * through the use of an intermediate <code>JPanel</code>
 * <p>
 * Screen snapshot<br>
 * <center><img src = "img/DemoBasic_v2-1.gif"></center>
 * <p>
 * 
 * @see <a href="../DemoBasic_v2.java">source code</a>
 * @author M. Baljko, 2004
 */
public class DemoBasicV2 {
	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}

	private static void createAndShowGUI() {
		JFrame frame = new DemoBasicFrameV2();
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setTitle(frame.getClass().getName());
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}

}

class DemoBasicFrameV2 extends JFrame {
	public DemoBasicFrameV2() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		// Step 1: Create and Configure Components
		JLabel sampleLabel = new JLabel("Sample Label");
		sampleLabel.setPreferredSize(new Dimension(250, 100));
		sampleLabel.setFont(new Font("sanserif", Font.PLAIN, 16));

		// Step 2: Register Listeners
		/*
		 * sampleLabel *cannot* react to user actions, no listener can be
		 * registered
		 */

		// Step 3: Arrange components in contentPane
		JPanel panel = new JPanel();
		panel.add(sampleLabel);
		setContentPane(panel);
	}
}
