package exampleSet1;
import java.awt.*;
import javax.swing.*;

import java.awt.event.*;

/**
 * <code>DemoBasic_v4</code> is similar to <code>DemoBasic_v3</code>. The
 * difference concerns how the <code>ActionListener</code> is created. In v3,
 * it is an instance of the class <code>MyListener</code>, which we defined
 * to implements <code>ActionListener</code>, whereas in v4, the class
 * <code>DemoBasicFrame</code> implements <code>ActionListener</code>.
 * <p>
 * Screen snapshot<br>
 * <center><img src = "img/DemoBasic_v4-1.gif"></center>
 * <p>
 * 
 * @see <a href="../DemoBasic_v4.java">source code</a>
 * @author M. Baljko, 2004
 */
public class DemoBasicV4 {
	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}

	private static void createAndShowGUI() {
		JFrame frame = new BasicFrameV4();
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setTitle(frame.getClass().getName());
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}
}

class BasicFrameV4 extends JFrame implements ActionListener {
	JLabel sampleLabel;
	JButton toggleButton;

	public BasicFrameV4() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		// Step 1: Create and Configure Components
		sampleLabel = new JLabel("Sample Label");
		sampleLabel.setPreferredSize(new Dimension(250, 100));
		sampleLabel.setFont(new Font("sanserif", Font.PLAIN, 16));

		toggleButton = new JButton("Press me!");
		toggleButton.setFont(new Font("sanserif", Font.PLAIN, 16));

		// Step 2: Register Listeners
		toggleButton.addActionListener(this);

		// Step 3: Arrange components in contentPane
		JPanel panel = new JPanel();
		panel.add(sampleLabel);
		panel.add(toggleButton);
		setContentPane(panel);
	}

	public boolean isLowerCase(String s) {
		return s.equals(s.toLowerCase());
	}

	// We provide a body for this method to satisfy the
	// requirement that this class
	// implements the interface ActionListener
	public void actionPerformed(ActionEvent ae) {
		if (ae.getSource() == toggleButton) {
			System.out.println("toggleButton generated ActionEvent");
			if (isLowerCase(sampleLabel.getText()))
				sampleLabel.setText(sampleLabel.getText().toUpperCase());
			else
				sampleLabel.setText(sampleLabel.getText().toLowerCase());
		}
	}
} // end of class DemoBasicFrame
