package exampleSet1;
import javax.swing.*;

import java.awt.event.*;

/**
 * <code>DemoBasicFrame_v5</code> is just like <code>DemoBasicFrame_v4</code>
 * except it provides non-empty method bodies for all of the methods in the
 * WindowListener interface. For all the methods, information is printed to the
 * console. You can use this application to see the attributes for all of the
 * WindowEvents that get generated
 * 
 * @see <a href="../DemoVeryBasic_v5.java">source code</a>
 * @author M. Baljko, 2004
 */
public class DemoVeryBasicV5 {
	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}

	private static void createAndShowGUI() {
		JFrame frame = new VeryBasicFrameV5();
		frame.setTitle(frame.getClass().getName());
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}
}

class VeryBasicFrameV5 extends JFrame {

	public VeryBasicFrameV5() {
		setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
		addWindowListener(new myWindowListener());
	}

	// named inner class to extend WindowAdapter
	class myWindowListener extends WindowAdapter {
		private int eventCounter = 0;

		private String toStringBasicInfoAndIncrementCounter(WindowEvent e) {
			StringBuffer buf = new StringBuffer();
			buf.append("Event #" + eventCounter++ + "\n");
			buf.append(e + "\n");
			buf.append(e.paramString() + "\n");
			buf.append("***********************" + "\n");
			return buf.toString();
		}

		public void windowClosing(WindowEvent e) {
			System.out.println("in windowClosing method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
			System.exit(0);
		}

		public void windowActivated(WindowEvent e) {
			System.out.println("in windowActivated method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
		}

		public void windowClosed(WindowEvent e) {
			System.out.println("in windowClosed method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
		}

		public void windowDeactivated(WindowEvent e) {
			System.out.println("in windowDeactivated method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
		}

		public void windowDeiconified(WindowEvent e) {
			System.out.println("in windowDeiconified method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
		}

		public void windowIconified(WindowEvent e) {
			System.out.println("in windowIconified method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
		}

		public void windowOpened(WindowEvent e) {
			System.out.println("in windowOpened method");
			System.out.println(toStringBasicInfoAndIncrementCounter(e));
		}
	}
}